@@ -19,6 +19,8 @@ from nwon_django_toolbox.tests.api_helper import (
     check_put_parameters_failing,
     check_put_parameters_successful,
     check_put_read_only_field,
+    ensure_key_with_object_list,
+    ensure_paged_results,
 )
 from nwon_django_toolbox.tests.celery import (
     check_latest_task,
@@ -73,4 +75,6 @@ __all__ = [
     "check_object_against_parameter",
     "ApiClient",
     "ApiTest",
+    "ensure_paged_results",
+    "ensure_key_with_object_list",
 ]
